@@ -6,7 +6,7 @@ use warnings;
 use Carp qw/croak/;
 use version;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Class::XSAccessor
   getters => {
@@ -16,10 +16,11 @@ use Class::XSAccessor
 
 sub _par_loader_hint {
   require Perl::APIReference::Generator;
-  require Perl::APIReference::V5_016_003;
+  require Perl::APIReference::V5_018_000;
 }
 
 our %Perls = (
+  5.018000 => 'V5_018_000',
   5.016003 => 'V5_016_003',
   5.016002 => 'V5_016_002',
   5.016001 => 'V5_016_001',
@@ -51,9 +52,10 @@ our %Perls = (
   5.006    => 'V5_006_000',
 );
 
-our $NewestAPI       = '5.016003';
-our $NewestStableAPI = '5.016003';
+our $NewestAPI       = '5.018000';
+our $NewestStableAPI = '5.018000';
 
+$Perls{'5.018000'} = $Perls{5.018};
 $Perls{'5.016000'} = $Perls{5.016};
 $Perls{'5.014000'} = $Perls{5.014};
 $Perls{'5.012000'} = $Perls{5.012};
@@ -172,7 +174,7 @@ Perl::APIReference - Programmatically query the perlapi
 This module allows accessing the perlapi documentation for multiple
 releases of perl as an index (a hash).
 
-Currently, the stable releases perl 5.16.0-3, 5.14.0-3,
+Currently, the stable releases perl 5.18.0, 5.16.0-3, 5.14.0-3,
 5.12.0-4, 5.10.0-1, 5.8.0-9, and 5.6.0-2
 are supported. To add support for another release, simply send me the
 release's F<perlapi.pod> via email or via an RT ticket and I'll add it
